#include "hostenv.h"
#ifdef	HAVE_SYS_SOCKET_H
# include <sys/socket.h>
# include <netinet/in.h>
#endif
#include "relaytest.h"

void reldefine(relp,dbtype,dbpath)
struct relaytest **relp;
char *dbtype, *dbpath;
{
}


int reltestaddr(rel,raddr)
     struct relaytest *rel;
     struct sockaddr_in *raddr;
{
  return 1;
}

int reltest(rel,str)
     struct relaytest *rel;
     char *str;
{
	/* XX: until we really test something... */

	return 1;
}
