/* relay-blocking tests;  Added for ZMailer 2.99.44 by Matti Aarnio
   on 16-Dec-96 */


struct relaytest {
	int x;
};


extern void reldefine __((struct relaytest **relp,char *dbtype, char *dbpath));
extern int  reltest   __((struct relaytest *rel, char *str));
extern int  reladdrtest __((struct relaytest *rel, struct sockaddr_in *raddr));
